@@ -1,3 +1,3 @@
 __package__ = 'dsocli.provider.template.local.v1'
-from .main import default_spec
+from .main import get_default_spec
 from .main import LocalTemplateProvider
